@@ -17,19 +17,21 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 @author Salvo "LtWorf" Tomaselli <tiposchi@tiscali.it>
  */
-
-#include "buffered_reader.h"
 #include "options.h"
+
 #include <unistd.h>
 #include <stdlib.h>
 #include <string.h>
 #include <poll.h>
 
+#include "buffered_reader.h"
+#include "types.h"
+
 /**
 This funcion inits the struct allocating a buffer of the specified size.
 It will return 0 on success and 1 on fail.
 */
-short int buffer_init(buffered_read_t * buf, ssize_t size) {
+int buffer_init(buffered_read_t * buf, ssize_t size) {
     buf->buffer = malloc(sizeof(char) * size);
     buf->size = size;
     buffer_reset(buf);
@@ -51,6 +53,34 @@ void buffer_free(buffered_read_t * buf) {
     free(buf->buffer);
 }
 
+static ssize_t buffer_fill(int fd, buffered_read_t * buf) {
+    ssize_t r;
+
+    buf->start = buf->buffer;
+
+    //Timeout implementation
+    struct pollfd monitor[1];
+    monitor[0].fd = fd; //File descriptor to monitor
+    monitor[0].events = POLLIN; //Monitor on input events
+
+    //Waits the timeout or reads the data.
+    //If timeout is reached and no input is available
+    //will behave like the stream is closed.
+    if (poll(monitor, 1, READ_TIMEOUT) == 0) {
+        r = 0;
+    } else {
+        r = read(fd, buf->buffer, buf->size);
+    }
+
+    if (r <= 0) { //End of the stream
+        buf->end = buf->start;
+    } else {
+        buf->end = buf->start + r;
+    }
+
+    return r;
+}
+
 /**
 This function is designed to be similar to a normal read, but it uses an internal
 buffer.
@@ -64,7 +94,7 @@ end of file is reached and it is impossible to do further reads.
 ssize_t buffer_read(int fd, void *b, ssize_t count, buffered_read_t * buf) {
     ssize_t wrote = 0;              //Count of written bytes
     ssize_t available, needed;      //Available bytes in buffer, and requested bytes remaining
-    ssize_t r;
+
 
     while (wrote < count) {
         available = buf->end - buf->start;
@@ -81,29 +111,9 @@ ssize_t buffer_read(int fd, void *b, ssize_t count, buffered_read_t * buf) {
                 wrote += available;
             }
             //Filing the buffer again
-            buf->start = buf->buffer;
-
-            {
-                //Timeout implementation
-                struct pollfd monitor[1];
-                monitor[0].fd = fd; //File descriptor to monitor
-                monitor[0].events = POLLIN; //Monitor on input events
-
-                //Waits the timeout or reads the data.
-                //If timeout is reached and no input is available
-                //will behave like the stream is closed.
-                if (poll(monitor, 1, READ_TIMEOUT) == 0) {
-                    r = 0;
-                } else {
-                    r = read(fd, buf->buffer, buf->size);
-                }
-            }
-
-            if (r <= 0) { //End of the stream
-                buf->end = buf->start;
+            if (buffer_fill(fd,buf) <= 0) { //End of the stream
                 return wrote;
             }
-            buf->end = buf->start + r;
         }
 
     } /*while */
@@ -111,7 +121,35 @@ ssize_t buffer_read(int fd, void *b, ssize_t count, buffered_read_t * buf) {
 }
 
 
-/*#include <sys/types.h>
+/**
+ * This function returns how many bytes must be read in order to
+ * read enough data for it to end with the string needle.
+ * strlen(needle) must be added to the returned value to include the
+ * needle string in the result of the read.
+ *
+ * If the string needle is not in the buffer then the entire size
+ * of the data present in cache will be return.
+ * */
+size_t buffer_strstr(int fd, buffered_read_t * buf, char * needle) {
+    if (buf->end - buf->start==0) {
+        buffer_fill(fd,buf);
+    }
+
+    buf->end[0]=0;
+    char *r=strstr(buf->start,needle);
+
+    if (r==NULL) {
+        return buf->end - buf->start;
+    } else {
+        return r-buf->start;
+
+    }
+
+}
+
+
+/*#include <stdio.h>
+#include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
 
@@ -124,13 +162,19 @@ int main () {
     char * k=malloc (600);
 
     int end=0;
-    while ((end=buffer_read(fp,k,500,&buf))>=500 ) {
+
+    while (1) {
+
+        int size=buffer_strstr(fp,&buf,"\n")+1;
+        end=buffer_read(fp,k,size,&buf);
+        if (end<size || end==0) break;
 
         k[end]=0;
-        printf("---- %s\n",k);
+        printf("%d ---- %s\n",size,k);
     }
     printf("%d",end);
 
     free(k);
     buffer_free(&buf);
-}*/
+}
+*/
