@@ -38,6 +38,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include "mystring.h"
 #include "utils.h"
+#include "embedded_auth.h"
 
 /**
 This function reads the directory dir, putting inside the html string an html
@@ -160,7 +161,49 @@ void version() {
 
            "Written by Salvo 'LtWorf' Tomaselli and Salvo Rinaldi.\n"
            "Synchronized queue by Prof. Giuseppe Pappalardo.\n\n"
-           "https://galileo.dmi.unict.it/wiki/weborf/\n", VERSION);
+           "http://ltworf.github.io/weborf/\n", VERSION);
+    exit(0);
+}
+
+void print_capabilities() {
+    printf("version:" VERSION "\n");
+
+    printf("ipv:"
+#ifdef IPV6
+    "6"
+#else
+    "4"
+#endif
+    "\n"
+    );
+
+    printf("webdav:"
+#ifdef WEBDAV
+    "yes"
+#else
+    "no"
+#endif
+    "\n"
+    );
+
+    printf("mime:"
+#ifdef SEND_MIMETYPES
+    "yes"
+#else
+    "no"
+#endif
+    "\n"
+    );
+
+    printf("embedded_auth:"
+#ifdef EMBEDDED_AUTH
+    "yes"
+#else
+    "no"
+#endif
+    "\n"
+    );
+
     exit(0);
 }
 
@@ -197,6 +240,7 @@ void help() {
            "  -h, --help    display this help and exit\n"
            "  -I, --index   list of index files, comma-separated\n"
            "  -i, --ip  followed by IP address to listen (dotted format)\n"
+           "  -k, --caps    lists the capabilities of the binary\n"
            "  -m, --mime    sends content type header to clients\n"
            "  -p, --port    followed by port number to listen\n"
            "  -T  --inetd   must be specified when using weborf with inetd or xinetd\n"
@@ -236,7 +280,7 @@ void print_start_disclaimer(int argc, char *argv[]) {
     printf("Weborf\n"
            "This program comes with ABSOLUTELY NO WARRANTY.\n"
            "This is free software, and you are welcome to redistribute it\n"
-           "under certain conditions.\nFor details see the GPLv3 Licese.\n"
+           "under certain conditions.\nFor details see the GPLv3 License.\n"
            "Run %s --help to see the options\n", argv[0]);
 }
 
